@@ -2,9 +2,10 @@
 """Art parameters."""
 from .text_dic1 import *
 from .text_dic2 import *
+from .text_dic3 import *
 from .art_dic import *
 
-VERSION = "3.6"  # pragma: no cover
+ART_VERSION = "4.1"  # pragma: no cover
 FONT_SMALL_THRESHOLD = 50  # pragma: no cover
 FONT_MEDIUM_THRESHOLD = 100  # pragma: no cover
 FONT_LARGE_THRESHOLD = 200  # pragma: no cover
@@ -21,8 +22,9 @@ FONT_TYPE_ERROR = "The 'font' type must be str."
 CHR_IGNORE_TYPE_ERROR = "The 'chr_ignore' type must be bool."
 FILE_TYPE_ERROR = "The 'filename' type must be str."
 PRINT_STATUS_TYPE_ERROR = "The 'print_status' type must be bool."
-ART_ENVIRONMENT_WARNING = "[Warning] This art is not printable in this environment."
-FONT_ENVIRONMENT_WARNING = "[Warning] This font is not printable in this environment."
+OVERWRITE_TYPE_ERROR = "The 'overwrite' type must be bool."
+ART_ENVIRONMENT_WARNING = "[Warning] '{0}' is not printable in this environment."
+FONT_ENVIRONMENT_WARNING = "[Warning] '{0}' is not printable in this environment."
 PACKAGE_LOAD_WARNING = "[Warning] There is a problem loading the package 'coverage'."
 
 SMALL_WIZARD_FONT = [
@@ -74,7 +76,6 @@ UPPERCASE_FONTS = [
     "asslt_m",
     "atc",
     "atc_gran",
-    "battle_s",
     "battlesh",
     "baz_bil",
     "beer_pub",
@@ -133,12 +134,17 @@ UPPERCASE_FONTS = [
 RANDOM_FILTERED_FONTS = [
     "5x8",
     "binary",
+    "contouring1",
+    "contouring2",
+    "contouring3",
+    "contouring4",
     "decimal",
     "high_noo",
     "hills",
     "katakana",
+    "love1",
+    "love2",
     "morse",
-    "morse2",
     "nfi1",
     "octal",
     "rot13",
@@ -159,9 +165,6 @@ RANDOM_FILTERED_FONTS = [
     "full_width",
     "antrophobia",
     "currency",
-    "magical",
-    "paranormal",
-    "sorcerer",
     "special",
     "dirty",
     "knight",
@@ -193,7 +196,71 @@ RANDOM_FILTERED_FONTS = [
     "fancy24",
     "fancy25",
     "fancy26",
-    "fancy27"]
+    "fancy27",
+    "fancy28",
+    "fancy29",
+    "fancy30",
+    "symbols",
+    "fancy31",
+    "fancy32",
+    "fancy33",
+    "fancy34",
+    "fancy35",
+    "fancy36",
+    "fancy37",
+    "fancy38",
+    "fancy39",
+    "fancy40",
+    "fancy41",
+    "fancy42",
+    "fancy43",
+    "fancy44",
+    "fancy45",
+    "fancy46",
+    "fancy47",
+    "fancy48",
+    "fancy49",
+    "fancy50",
+    "fancy51",
+    "fancy52",
+    "fancy53",
+    "fancy54",
+    "fancy55",
+    "fancy56",
+    "fancy57",
+    "fancy58",
+    "fancy59",
+    "fancy60",
+    "fancy61",
+    "fancy62",
+    "fancy63",
+    "fancy64",
+    "fancy65",
+    "fancy66",
+    "fancy67",
+    "fancy68",
+    "fancy69",
+    "fancy70",
+    "fancy71",
+    "fancy72",
+    "fancy73",
+    "fancy74",
+    "fancy75",
+    "fancy76",
+    "fancy77",
+    "fancy78",
+    "fancy79",
+    "fancy80",
+    "fancy81",
+    "fancy82",
+    "fancy83",
+    "fancy84",
+    "fancy85",
+    "fancy86",
+    "white_square",
+    "black_square",
+    "paranormal",
+    "black_bubble"]
 
 RANDOM_FILTERED_ARTS = [
     "message2",
@@ -204,6 +271,10 @@ RANDOM_FILTERED_ARTS = [
 
 
 TEST_FILTERED_FONTS = [
+    "contouring1",
+    "contouring2",
+    "contouring3",
+    "contouring4",
     "mirror",
     "mirror_flip",
     "flip",
@@ -214,14 +285,13 @@ TEST_FILTERED_FONTS = [
     "full_width",
     "antrophobia",
     "currency",
-    "magical",
-    "paranormal",
-    "sorcerer",
     "special",
     "dirty",
     "knight",
     "thin2",
     "tiny",
+    "love1",
+    "love2",
     "fancy1",
     "fancy2",
     "fancy3",
@@ -248,7 +318,71 @@ TEST_FILTERED_FONTS = [
     "fancy24",
     "fancy25",
     "fancy26",
-    "fancy27"]
+    "fancy27",
+    "fancy28",
+    "fancy29",
+    "fancy30",
+    "symbols",
+    "fancy31",
+    "fancy32",
+    "fancy33",
+    "fancy34",
+    "fancy35",
+    "fancy36",
+    "fancy37",
+    "fancy38",
+    "fancy39",
+    "fancy40",
+    "fancy41",
+    "fancy42",
+    "fancy43",
+    "fancy44",
+    "fancy45",
+    "fancy46",
+    "fancy47",
+    "fancy48",
+    "fancy49",
+    "fancy50",
+    "fancy51",
+    "fancy52",
+    "fancy53",
+    "fancy54",
+    "fancy55",
+    "fancy56",
+    "fancy57",
+    "fancy58",
+    "fancy59",
+    "fancy60",
+    "fancy61",
+    "fancy62",
+    "fancy63",
+    "fancy64",
+    "fancy65",
+    "fancy66",
+    "fancy67",
+    "fancy68",
+    "fancy69",
+    "fancy70",
+    "fancy71",
+    "fancy72",
+    "fancy73",
+    "fancy74",
+    "fancy75",
+    "fancy76",
+    "fancy77",
+    "fancy78",
+    "fancy79",
+    "fancy80",
+    "fancy81",
+    "fancy82",
+    "fancy83",
+    "fancy84",
+    "fancy85",
+    "fancy86",
+    "white_square",
+    "black_square",
+    "paranormal",
+    "black_bubble"]
 
 DESCRIPTION = '''ASCII art is also known as "computer text art".
 It involves the smart placement of typed special characters or
@@ -390,17 +524,13 @@ FONT_MAP = {"block": [block_dic, True], "banner": [banner_dic, False],  # pragma
             "merlin2": [merlin2_dic, True],
             "modular": [modular_dic, True],
             "morse": [morse_dic, True],
-            "morse2": [morse2_dic, True],
             "moscow": [moscow_dic, True],
             "muzzle": [muzzle_dic, True],
-            "nancyj-improved": [nancyj_improved_dic, False],
             "nscript": [nscript_dic, False],
-            "ntgreek": [ntgreek_dic, False],
             "nvscript": [nvscript_dic, False],
             "octal": [octal_dic, False],
             "oldbanner": [oldbanner_dic, False],
             "os2": [os2_dic, False],
-            "peaksslant": [peaksslant_dic, False],
             "puzzle": [puzzle_dic, True],
             "rammstein": [rammstein_dic, False],
             "red_phoenix": [red_phoenix_dic, False],
@@ -435,7 +565,6 @@ FONT_MAP = {"block": [block_dic, True], "banner": [banner_dic, False],  # pragma
             "b1ff": [B1FF_dic, True],
             "dwhistled": [dwhistled_dic, False],
             "eftiwall": [eftiwall_dic, False],
-            "fire_font-k": [fire_font_k_dic, False],
             "fire_font-s": [fire_font_s_dic, False],
             "gradient": [gradient_dic, True],
             "1943": [dic_1943, False],
@@ -495,7 +624,6 @@ FONT_MAP = {"block": [block_dic, True], "banner": [banner_dic, False],  # pragma
             "asslt_m": [asslt__m_dic, False],
             "atc": [atc_dic, False],
             "atc_gran": [atc_gran_dic, False],
-            "battle_s": [battle_s_dic, False],
             "battlesh": [battlesh_dic, False],
             "baz_bil": [baz_bil_dic, False],
             "beer_pub": [beer_pub_dic, False],
@@ -518,6 +646,7 @@ FONT_MAP = {"block": [block_dic, True], "banner": [banner_dic, False],  # pragma
             "vortron": [vortron_dic, False],
             "war_of_w": [war_of_w_dic, False],
             "xtty": [xtty_dic, False],
+            "love1": [love1_dic, False],
             "yie_ar_k": [yie_ar_k_dic, False],
             "yie-ar": [yie_ar_dic, False],
             "zig_zag": [zig_zag_dic, False],
@@ -542,6 +671,8 @@ FONT_MAP = {"block": [block_dic, True], "banner": [banner_dic, False],  # pragma
             "clr8x8": [clr8x8_dic, False],
             "clr8x10": [clr8x10_dic, False],
             "coil_cop": [coil_cop_dic, False],
+            "contouring1": [contouring1_dic, False],
+            "contouring2": [contouring2_dic, True],
             "com_sen": [com_sen_dic, False],
             "druid": [druid_dic, False],
             "e_fist": [e_fist_dic, True],
@@ -588,9 +719,6 @@ FONT_MAP = {"block": [block_dic, True], "banner": [banner_dic, False],  # pragma
             "full_width": [full_width_dic, False],
             "antrophobia": [antrophobia_dic, False],
             "currency": [currency_dic, False],
-            "magical": [magic_dic, False],
-            "paranormal": [paranormal_dic, False],
-            "sorcerer": [sorcerer_dic, False],
             "special": [special_dic, False],
             "dirty": [dirty_dic, False],
             "knight": [knight_dic, False],
@@ -622,7 +750,74 @@ FONT_MAP = {"block": [block_dic, True], "banner": [banner_dic, False],  # pragma
             "fancy24": [fancy24_dic, False],
             "fancy25": [fancy25_dic, False],
             "fancy26": [fancy26_dic, False],
-            "fancy27": [fancy27_dic, False]
+            "fancy27": [fancy27_dic, False],
+            "fancy28": [fancy28_dic, False],
+            "fancy29": [fancy29_dic, False],
+            "fancy30": [fancy30_dic, False],
+            "symbols": [symbols_dic, False],
+            "fancy31": [fancy31_dic, False],
+            "fancy32": [fancy32_dic, False],
+            "fancy33": [fancy33_dic, False],
+            "fancy34": [fancy34_dic, False],
+            "fancy35": [fancy35_dic, False],
+            "fancy36": [fancy36_dic, False],
+            "fancy37": [fancy37_dic, False],
+            "fancy38": [fancy38_dic, False],
+            "fancy39": [fancy39_dic, False],
+            "fancy40": [fancy40_dic, False],
+            "fancy41": [fancy41_dic, False],
+            "fancy42": [fancy42_dic, False],
+            "fancy43": [fancy43_dic, False],
+            "fancy44": [fancy44_dic, False],
+            "fancy45": [fancy45_dic, False],
+            "fancy46": [fancy46_dic, False],
+            "fancy47": [fancy47_dic, False],
+            "fancy48": [fancy48_dic, False],
+            "fancy49": [fancy49_dic, False],
+            "fancy50": [fancy50_dic, False],
+            "fancy51": [fancy51_dic, False],
+            "fancy52": [fancy52_dic, False],
+            "fancy53": [fancy53_dic, False],
+            "fancy54": [fancy54_dic, False],
+            "fancy55": [fancy55_dic, False],
+            "fancy56": [fancy56_dic, False],
+            "fancy57": [fancy57_dic, False],
+            "fancy58": [fancy58_dic, False],
+            "fancy59": [fancy59_dic, False],
+            "fancy60": [fancy60_dic, False],
+            "fancy61": [fancy61_dic, False],
+            "fancy62": [fancy62_dic, False],
+            "fancy63": [fancy63_dic, False],
+            "fancy64": [fancy64_dic, False],
+            "fancy65": [fancy65_dic, False],
+            "fancy66": [fancy66_dic, False],
+            "fancy67": [fancy67_dic, False],
+            "fancy68": [fancy68_dic, False],
+            "fancy69": [fancy69_dic, False],
+            "fancy70": [fancy70_dic, False],
+            "fancy71": [fancy71_dic, False],
+            "fancy72": [fancy72_dic, False],
+            "fancy73": [fancy73_dic, False],
+            "fancy74": [fancy74_dic, False],
+            "fancy75": [fancy75_dic, False],
+            "fancy76": [fancy76_dic, False],
+            "fancy77": [fancy77_dic, False],
+            "fancy78": [fancy78_dic, False],
+            "fancy79": [fancy79_dic, False],
+            "fancy80": [fancy80_dic, False],
+            "fancy81": [fancy81_dic, False],
+            "fancy82": [fancy82_dic, False],
+            "fancy83": [fancy83_dic, False],
+            "fancy84": [fancy84_dic, False],
+            "contouring3": [contouring3_dic, False],
+            "contouring4": [contouring4_dic, False],
+            "love2": [love2_dic, False],
+            "fancy85": [fancy85_dic, False],
+            "fancy86": [fancy86_dic, False],
+            "white_square": [white_square_dic, False],
+            "black_square": [black_square_dic, False],
+            "paranormal": [paranormal_dic, False],
+            "black_bubble": [black_bubble_dic, False]
             }
 
 FONT_COUNTER = len(FONT_MAP)  # pragma: no cover
